# GetPaymentMethodSnapshotResponseAchAccountType

The type of bank account associated with the ACH payment.

## Enum

* `BUSINESSCHECKING` (value: `'BusinessChecking'`)

* `CHECKING` (value: `'Checking'`)

* `SAVING` (value: `'Saving'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


